﻿# 3_prepare_folders.ps1 - Creates a file with current MailStore folder names.
#                         That file can be used in the 4_update_folders.ps1 script.
#
# Copyright (c) 2017 - 2018 MailStore Software GmbH
# 
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

# Adjust the path to the psd1 file
# https://help.mailstore.com/en/server/PowerShell_API_Wrapper_Tutorial

Import-Module 'C:\zen\MS.PS.Lib.psd1'

# Adjust these values according to your installation
$username = "admin"
$password = "admin"
$hostname = "localhost"
$port = 8463
$filename = ($env:HOMEDRIVE + $env:HOMEPATH + "\mailstore-users.csv")

############### FUNCTIONS CAN BE ADJUSTED TO MODIFY FOLDER I/O ###############

function Check-Folder($folder) {
    return $folder.fullName.Split("/")[1].StartsWith("Exchange")
}

function Prepare-Output($folderFullNames) {
    return ($folderFullNames | ForEach-Object { ($_ + "=" + $_) })
}

################### DO NOT CHANGE ANYTHING BELOW THIS LINE ###################

function Has-Succeeded($result) {
    if ($result.statusCode -ne "succeeded") {
        Write-Host ("Status  " + $result.statusCode)
        Write-Host ("Message " + $result.error.message)
        Write-Host ("Details " + $result.error.details)
        return $false
    }
    return $true
}

function My-Exit() {
    if (-not (Test-Path variable:global:psISE)) {
        Read-Host -Prompt "Press [Enter] to exit script"
    }
    exit
}

Write-Output "Creating API client"
$msapiclient = New-MSApiClient -Username $username -Password $password -MailStoreServer $hostname -Port $port -IgnoreInvalidSSLCerts

$compliance_configuration_result = Invoke-MSApiCall $msapiclient "GetComplianceConfiguration"

if (-not (Has-Succeeded($compliance_configuration_result))) {
    Write-Output "Error while fetching compliance configuration."
    My-Exit
}
 
if (-not ($compliance_configuration_result.result.adminEmailPreviewEnabled)) {
    Write-Output "Archive Access is disabled for admins, but has to be enabled. Aborting script execution."
    My-Exit
}

$get_folders_result = Invoke-MSApiCall $msapiclient "GetChildFolders" @{maxLevels = 2}

if (-not (Has-Succeeded($get_folders_result))) {
    Write-Output "Error while fetching folder hierarchy."
    My-Exit
} else {
    $get_folders = $get_folders_result.result
}

$exchange_folders = [System.Collections.ArrayList]@()

foreach ($folder in $get_folders.childFolders) {
    foreach ($subfolder in $folder.childFolders) {
        if (Check-Folder($subfolder)) {
            $exchange_folders.Add($subfolder.fullName) | Out-Null       
        }
    }
}

Write-Output ("Writing folders to file " + $filename)
Prepare-Output($exchange_folders) | Out-File $filename
&explorer.exe (Split-Path -Path $filename)

My-Exit
